CFErrorResponse class
Represents an error or failure response from the Cashfree payment gateway.
Returned via the onError callback registered in CFPaymentGatewayService.setCallback.
Constructors
- CFErrorResponse(String? status, String? message, String? code, String? type)
-
Creates a CFErrorResponse with the given
status,message,code, andtype.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getCode(
) → String? -
Returns the error code (e.g.,
"invalid_request"). -
getMessage(
) → String? - Returns the human-readable error message.
-
getStatus(
) → String? -
Returns the status string (e.g.,
"FAILED"). -
getType(
) → String? -
Returns the error type (e.g.,
"invalid_request"). -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited