CFNetbanking class

Represents a netbanking payment method configuration.

Create instances using CFNetbankingBuilder.

Constructors

CFNetbanking(CFNetbankingBuilder builder)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBankCode() int
Returns the bank code for the selected netbanking bank.
getChannel() String
Returns the payment channel string.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited