getBankCode method
Returns the bank code for the selected netbanking bank.
Implementation
int getBankCode() {
return _netbanking_bank_code!;
}
Returns the bank code for the selected netbanking bank.
int getBankCode() {
return _netbanking_bank_code!;
}