CFNetbankingBuilder class

Builder for creating a CFNetbanking payment method object.

Example:

final netbanking = CFNetbankingBuilder()
  .setBankCode(3003)
  .build();

Constructors

CFNetbankingBuilder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() CFNetbanking
Builds and returns a CFNetbanking object.
getBankCode() int
getChannel() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBankCode(int bank_code) CFNetbankingBuilder
Sets the bank code for the selected netbanking bank.
setChannel(String channel) CFNetbankingBuilder
Sets the payment channel. Defaults to "link".
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited