CFNetbankingPayment class
Represents a complete netbanking payment object ready for submission.
Create instances using CFNetbankingPaymentBuilder.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getNetbanking(
) → CFNetbanking - Returns the CFNetbanking payment method details.
-
getSession(
) → CFSession - Returns the CFSession associated with this payment.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited