CFUPIPayment class
Represents a complete UPI payment object ready for submission.
Create instances using CFUPIPaymentBuilder.
Constructors
- CFUPIPayment(CFUPIPaymentBuilder builder)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getSession(
) → CFSession - Returns the CFSession associated with this payment.
-
getUPI(
) → CFUPI - Returns the CFUPI payment method details.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited