CFUPIPaymentBuilder class

Builder for creating a CFUPIPayment object.

Example:

final payment = CFUPIPaymentBuilder()
  .setSession(session)
  .setUPI(upi)
  .build();

Constructors

CFUPIPaymentBuilder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() CFUPIPayment
Validates required fields and returns a CFUPIPayment.
getSession() CFSession
getUPI() CFUPI
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setSession(CFSession session) CFUPIPaymentBuilder
Sets the CFSession for this payment.
setUPI(CFUPI cfupi) CFUPIPaymentBuilder
Sets the CFUPI payment method details.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited