CFSubsUPIBuilder class

Constructors

CFSubsUPIBuilder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() CFSubsUPI
getChannel() CFSubsUPIChannel
getUPIID() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setChannel(CFSubsUPIChannel channel) CFSubsUPIBuilder
setUPIID(String upiId) CFSubsUPIBuilder
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited