CFSubscriptionSessionBuilder class

Builder for creating a CFSubscriptionSession for subscription element payments.

Example:

final session = CFSubscriptionSessionBuilder()
  .setEnvironment(CFEnvironment.SANDBOX)
  .setSubscriptionId("sub_123")
  .setSubscriptionSessionId("sub_session_abc")
  .build();

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() CFSubscriptionSession
Validates all required fields and returns a CFSubscriptionSession.
getEnvironment() CFEnvironment
getSubscriptionId() String
getSubscriptionSessionId() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setEnvironment(CFEnvironment environment) CFSubscriptionSessionBuilder
Sets the environment (CFEnvironment.SANDBOX or CFEnvironment.PRODUCTION).
setSubscriptionId(String subscriptionId) CFSubscriptionSessionBuilder
Sets the subscription ID obtained from the Cashfree Subscriptions API.
setSubscriptionSessionId(String subscriptionSessionID) CFSubscriptionSessionBuilder
Sets the subscription session ID for authenticating the subscription transaction.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited