CFTheme class

Holds the visual theme configuration for the Cashfree payment UI.

Create instances using CFThemeBuilder.

Constructors

CFTheme(CFThemeBuilder builder)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBackgroundColor() String
Returns the background color hex string.
getButtonBackgroundColor() String
Returns the button background color hex string.
getButtonTextColor() String
Returns the button text color hex string.
getNavigationBarBackgroundColor() String
Returns the navigation bar background color hex string.
getNavigationBarTextColor() String
Returns the navigation bar text color hex string.
getPrimaryFont() String
Returns the primary font family name.
getPrimaryTextColor() String
Returns the primary text color hex string.
getSecondaryFont() String
Returns the secondary font family name.
getSecondaryTextColor() String
Returns the secondary text color hex string.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited