CFNetbankingPaymentBuilder class
Builder for creating a CFNetbankingPayment object.
Example:
final payment = CFNetbankingPaymentBuilder()
.setSession(session)
.setNetbanking(netbanking)
.build();
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
) → CFNetbankingPayment - Validates required fields and returns a CFNetbankingPayment.
-
getNetbanking(
) → CFNetbanking -
getSession(
) → CFSession -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setNetbanking(
CFNetbanking cfNetbanking) → CFNetbankingPaymentBuilder - Sets the CFNetbanking payment method details.
-
setSession(
CFSession session) → CFNetbankingPaymentBuilder - Sets the CFSession for this payment.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited