CFWebCheckoutPayment class
Represents a complete web checkout payment object ready for submission.
Create instances using CFWebCheckoutPaymentBuilder.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getSession(
) → CFSession - Returns the CFSession associated with this payment.
-
getTheme(
) → CFTheme - Returns the CFTheme for this web checkout.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited