CFWebCheckoutPaymentBuilder class
Builder for creating a CFWebCheckoutPayment object.
Example:
final payment = CFWebCheckoutPaymentBuilder()
.setSession(session)
.setTheme(theme)
.build();
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
) → CFWebCheckoutPayment - Validates required fields and returns a CFWebCheckoutPayment.
-
getSession(
) → CFSession -
getTheme(
) → CFTheme -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setSession(
CFSession session) → CFWebCheckoutPaymentBuilder - Sets the CFSession for this payment.
-
setTheme(
CFTheme cfTheme) → CFWebCheckoutPaymentBuilder - Sets an optional CFTheme to customize the web checkout appearance.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited