CFSubsNetbankingBuilder class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
) → CFSubsNetbanking -
getAccountBankCode(
) → String? -
getAccountHolderName(
) → String? -
getAccountNumber(
) → String? -
getAccountType(
) → String? -
getAuthMode(
) → String? -
getChannel(
) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setAccountBankCode(
String accountBankCode) → CFSubsNetbankingBuilder -
setAccountHolderName(
String accountHolderName) → CFSubsNetbankingBuilder -
setAccountNumber(
String accountNumber) → CFSubsNetbankingBuilder -
setAccountType(
String accountType) → CFSubsNetbankingBuilder -
setAuthMode(
String authMode) → CFSubsNetbankingBuilder -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited