CFSession class
Represents an authenticated payment session for the Cashfree payment gateway.
Create instances using CFSessionBuilder.
Constructors
- CFSession(CFSessionBuilder sessionBuilder)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getEnvironment(
) → String -
Returns the environment string (
"SANDBOX"or"PRODUCTION"). -
getEnvironmentEnum(
) → CFEnvironment - Returns the CFEnvironment enum value for this session.
-
getOrderId(
) → String - Returns the order ID associated with this session.
-
getOrderToken(
) → String -
getPaymentSessionId(
) → String - Returns the payment session ID used to authenticate the transaction.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited