CFSubscriptionSession class
Represents an authenticated session for subscription element payments.
Create instances using CFSubscriptionSessionBuilder.
Constructors
- CFSubscriptionSession(CFSubscriptionSessionBuilder sessionBuilder)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getEnvironment(
) → String -
Returns the environment string (
"SANDBOX"or"PRODUCTION"). -
getSubscriptionId(
) → String - Returns the subscription ID associated with this session.
-
getSubscriptionSessionID(
) → String - Returns the subscription session ID used to authenticate the transaction.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited